package org.hisrc.hifaces20.tools.servlet;

import java.io.IOException;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;

public class PauseFilter implements Filter {

  private static final String PAUSE_PARAMETER_NAME = "PAUSE"; //$NON-NLS-1$

  private static final int PAUSE_MAX_VALUE = 100 * 1000;

  @Override
  public void destroy() {
    // Nothing to do
  }

  @Override
  public void doFilter(
      final ServletRequest request,
      final ServletResponse response,
      final FilterChain filterChain) throws ServletException, IOException {

    final String pauseValue = request.getParameter(PAUSE_PARAMETER_NAME);

    if (pauseValue != null) {
      try {
        final int pause = Integer.valueOf(pauseValue).intValue();
        if (pause < PAUSE_MAX_VALUE) {
          try {
            Thread.sleep(pause);
          }
          catch (final InterruptedException ignored) {
            // Nothing to do
          }
        }
        else {
          throw new ServletException("The value of the [PAUSE] parameter [" //$NON-NLS-1$
              + pause
              + "] exceeds the maximum allowed value [" //$NON-NLS-1$
              + PAUSE_MAX_VALUE
              + "]."); //$NON-NLS-1$
        }
      }
      catch (final NumberFormatException nfe) {
        throw new ServletException("The value of the [PAUSE] parameter [" //$NON-NLS-1$
            + pauseValue
            + "] could not be paused to an integer."); //$NON-NLS-1$
      }
    }
    filterChain.doFilter(request, response);
  }

  public void init(final FilterConfig arg0) {
    // Nothing to do
  }

}
